@@ -1292,19 +1292,6 @@ void DebuggerTestBase::testStack()
     COMPARE_DATA(stackModel->index(0, 1, threadIndex), "main");
     // As the What's This for KDevelop's Step Out action says, the debugger should
     // now display the line after the original call to the stepped-out function: 30.
-    if (!isLldb()) {
-        // On a given system, all GDB/MI output records consistently report a certain line number as current
-        // after the step-out. But for some reason since 2020 this MI line number is 29 (wrong) on the openSUSE
-        // Tumbleweed CI servers. The line number remains 30 (correct) on developers' local GNU/Linux systems
-        // and on the FreeBSD CI server. Work around the difference by accepting either line number.
-        // TODO: why does this difference in line numbers persists for many years?
-        //       Is this some openSUSE bug or a CI server configuration issue?
-        const auto currentLocation = stackModel->index(0, 2, threadIndex).data().toString();
-        if (currentLocation.endsWith(":29")) {
-            QCOMPARE(currentLocation, debugeeLocationAt(29));
-            QEXPECT_FAIL("", "Wrong line number after stepping out: 29 instead of the expected 30", Continue);
-        }
-    }
     COMPARE_DATA(stackModel->index(0, 2, threadIndex), debugeeLocationAt(30));
 
     CONTINUE_AND_WAIT_FOR_PAUSED_STATE(session, sessionSpy);
@@ -1898,6 +1885,96 @@ void DebuggerTestBase::testVariablesQuicklySwitchFrame()
     WAIT_FOR_STATE(session, IDebugSession::EndedState);
 }
 
+void DebuggerTestBase::testVariablesAttributes()
+{
+    auto* const session = createTestDebugSession();
+    TestLaunchConfiguration cfg;
+
+    variableCollection()->variableWidgetShown();
+
+    addDebugeeBreakpoint(24);
+    addDebugeeBreakpoint(29);
+    ActiveStateSessionSpy sessionSpy(session);
+    START_DEBUGGING_AND_WAIT_FOR_PAUSED_STATE_E(session, cfg, sessionSpy);
+
+    auto* const jVariable = variableCollection()->watches()->add("j");
+    QVERIFY(jVariable);
+    QCOMPARE(jVariable->canSetFormat(), true);
+    // Verify initialization of attributes in the constructor of a variable.
+    QCOMPARE(jVariable->expression(), "j");
+    QCOMPARE(jVariable->showError(), false);
+    QCOMPARE(jVariable->format(), Variable::Natural);
+
+    // Wait for the results of an MI command -var-create.
+    WAIT_FOR_STATE_AND_IDLE(session, IDebugSession::PausedState);
+    QCOMPARE(currentMiLine(session), 29);
+    // There is no variable named `j` in the scope of main().
+    QCOMPARE(jVariable->showError(), true);
+
+    // Setting format of a not yet attached variable succeeds but does not modify the value of the variable.
+    jVariable->setFormat(Variable::Octal);
+    QCOMPARE(jVariable->format(), Variable::Octal);
+
+    CONTINUE_AND_WAIT_FOR_PAUSED_STATE(session, sessionSpy);
+    QCOMPARE(currentMiLine(session), 24);
+    // A variable named `j` is present in the scope of foo().
+    QCOMPARE(jVariable->showError(), false);
+    QCOMPARE(jVariable->inScope(), true);
+    QCOMPARE(jVariable->type(), "int");
+    QCOMPARE(jVariable->format(), Variable::Octal);
+    QCOMPARE(jVariable->value(), "01");
+
+    CONTINUE_AND_WAIT_FOR_PAUSED_STATE(session, sessionSpy);
+    QCOMPARE(currentMiLine(session), 24);
+    QCOMPARE(jVariable->showError(), false);
+    QCOMPARE(jVariable->inScope(), true);
+    QCOMPARE(jVariable->type(), "int");
+    QCOMPARE(jVariable->format(), Variable::Octal);
+    QCOMPARE(jVariable->value(), "02");
+
+    jVariable->setFormat(Variable::Binary);
+    // Wait for the results of an MI command -var-set-format.
+    WAIT_FOR_STATE_AND_IDLE(session, IDebugSession::PausedState);
+    QCOMPARE(jVariable->showError(), false);
+    QCOMPARE(jVariable->inScope(), true);
+    QCOMPARE(jVariable->type(), "int");
+    QCOMPARE(jVariable->format(), Variable::Binary);
+    QCOMPARE(jVariable->value(), adjustedVariableValueInBinaryFormat("10"));
+
+    STEP_OUT_AND_WAIT_FOR_PAUSED_STATE(session, sessionSpy);
+    QCOMPARE(currentMiLine(session), 32);
+    // Back to main() where `j` is out of scope. The type and value of an out-of-scope variable remain unchanged.
+    QCOMPARE(jVariable->showError(), false);
+    if (isLldb()) {
+        // A workaround in LLDB::DebugSession::updateAllVariables() updates all variables manually.
+        // Consequently MIVariable::handleUpdate(), which updates Variable::inScope(), is not invoked regularly.
+        QEXPECT_FAIL("", "MIVariable::handleUpdate() is invoked only when the format of a variable changes", Continue);
+    }
+    QCOMPARE(jVariable->inScope(), false);
+    QCOMPARE(jVariable->type(), "int");
+    QCOMPARE(jVariable->format(), Variable::Binary);
+    QCOMPARE(jVariable->value(), adjustedVariableValueInBinaryFormat("10"));
+
+    jVariable->setFormat(Variable::Hexadecimal);
+    // Wait for the results of an MI command -var-set-format.
+    WAIT_FOR_STATE_AND_IDLE(session, IDebugSession::PausedState);
+    QCOMPARE(jVariable->showError(), false);
+    QCOMPARE(jVariable->inScope(), false);
+    QCOMPARE(jVariable->type(), "int");
+    QCOMPARE(jVariable->format(), Variable::Hexadecimal);
+    if (isLldb()) {
+        QCOMPARE(jVariable->value(), "0x2");
+    } else {
+        // GDB/MI sends value="", and SetFormatHandler assigns the empty string to Variable::value().
+        QEXPECT_FAIL("", "Changing format of an out-of-scope variable clears its value", Continue);
+        QCOMPARE(jVariable->value(), "0x2");
+        QCOMPARE(jVariable->value(), "");
+    }
+
+    session->run();
+    WAIT_FOR_STATE(session, IDebugSession::EndedState);
+}
+
 void DebuggerTestBase::testVariablesChanged()
 {
     // kdevlldb xfails the test because of a workaround in LLDB::DebugSession::updateAllVariables()
@@ -2199,6 +2276,14 @@ QString DebuggerTestBase::adjustedStackModelFrameName(QString frameName) const
     return frameName;
 }
 
+QString DebuggerTestBase::adjustedVariableValueInBinaryFormat(QString binaryValue) const
+{
+    if (isLldb()) {
+        binaryValue.prepend("0b");
+    }
+    return binaryValue;
+}
+
 bool DebuggerTestBase::isAcceptableExecutableFileKindForCore(FileKind executableFileKind)
 {
     return executableFileKind == FileKind::Valid || executableFileKind == FileKind::EmptyName;
